# FractAlgebra
A simple fraction calculator CLI

## Features
* Accepts arbitrarily many fractions, not just two at a time
* returns the answer in lowest common denominator

## Installing

 ### Using `pipx` (simple and quick 🚀)
 [pipx](https://github.com/pypa/pipx#pipx--install-and-run-python-applications-in-isolated-environments) allows you to install (or just test out using the `run` command) python CLIs safely using Isolated Environments
 
 _Requires Python 3.6 or greater_

 ### Downloadable Binary (TODO)

 ### Build From Source

## Usage

## Development
### Building the Project
### Environment Setup